@@ -37,12 +37,12 @@ BEGIN {
 
 use vars qw(@ISA @EXPORT %EXPORT_TAGS $VERSION %SubTests @SkipReasons);
 
-$VERSION = '1.38';
+$VERSION = '1.41';
 
 my @need = qw(need_lwp need_http11 need_cgi need_access need_auth
-              need_module need_apache need_min_apache_version
+              need_module need_apache need_min_apache_version need_min_apache_fix
               need_apache_version need_perl need_min_perl_version
-              need_min_module_version need_threads need_apache_mpm
+              need_min_module_version need_threads need_fork need_apache_mpm
               need_php need_php4 need_ssl need_imagemap need_cache_disk);
 
 my @have = map { (my $need = $_) =~ s/need/have/; $need } @need;
@@ -316,7 +316,7 @@ sub need_http11 {
 
 sub need_ssl {
     my $vars = vars();
-    need_module([$vars->{ssl_module_name}, 'Net::SSL']);
+    need_module([$vars->{ssl_module_name}, 'IO::Socket::SSL']);
 }
 
 sub need_lwp {
@@ -499,6 +499,37 @@ sub need_min_apache_version {
     }
 }
 
+sub need_min_apache_fix {
+    my @wantlevels = @_;
+    my $cfg = Apache::Test::config();
+    (my $current) = $cfg->{server}->{version} =~ m:^Apache/((\d)\.(\d+)\.(\d+)):;
+    my $current_major = $2;
+    my $current_minor = $3;
+    my $current_micro = $4;
+
+    foreach(@wantlevels) { 
+        if ($_ =~ m/(\d)\.(\d+)\.(\d+)/) { 
+            my $wanted_major = $1;
+            my $wanted_minor = $2;
+            my $wanted_micro = $3;
+            if ($wanted_major eq $current_major && $wanted_minor eq $current_minor) { 
+                if ($wanted_micro > $current_micro) {
+                    push @SkipReasons,
+                         "apache version $_ or higher is required," .
+                             " this is version $current";
+                    return 0;
+                }
+                else { 
+                    return 1;
+                }
+            }
+        }
+    }
+
+    # We didn't match major+minor, run the test and let the author sort it out
+    return 1;
+}
+
 sub need_apache_version {
     my $wanted = shift;
     my $cfg = Apache::Test::config();
@@ -594,6 +625,22 @@ sub need_threads {
     return $status;
 }
 
+sub need_fork {
+    my $have_fork = $Config{d_fork} ||
+                    $Config{d_pseudofork} ||
+                    (($^O eq 'MSWin32' || $^O eq 'NetWare') &&
+                     $Config{useithreads} &&
+                     $Config{ccflags} =~ /-DPERL_IMPLICIT_SYS/);
+
+     if (!$have_fork) {
+         push @SkipReasons, 'The fork function is unimplemented';
+         return 0;
+     }
+     else {
+         return 1;
+     }
+}
+
 sub under_construction {
     push @SkipReasons, "This test is under construction";
     return 0;
@@ -866,6 +913,16 @@ For example:
 
 requires Apache 2.0.40.
 
+=item need_min_apache_fix
+
+Used to require a particular micro version from corresponding minor release
+
+For example:
+
+  plan tests => 5, need_min_apache_fix("2.0.40", "2.2.30", "2.4.18");
+
+requires Apache 2.0.40 or higher.
+
 =item need_apache_mpm
 
 Used to require a specific Apache Multi-Processing Module.
@@ -899,6 +956,10 @@ For example:
 
 requires Perl 5.8.1 or higher.
 
+=item need_fork
+
+Requires the perl built-in function C<fork> to be implemented.
+
 =item need_module
 
   plan tests => 5, need_module 'CGI';
@@ -1020,6 +1081,8 @@ if no reason is given a default reason will be used.
 
 =head1 Additional Configuration Variables
 
+=over 4
+
 =item basic_config
 
   my $basic_cfg = Apache::Test::basic_config();
@@ -1052,6 +1115,8 @@ If no arguments are passed, the reference to the variables hash is
 returned. If one or more arguments are passed the corresponding values
 are returned.
 
+=back
+
 =head1 Test::More Integration
 
 There are a few caveats if you want to use I<Apache::Test> with
